@@ -49,10 +49,11 @@ from bloom.git import create_branch
 from bloom.git import ensure_clean_working_env
 from bloom.git import get_commit_hash
 from bloom.git import get_current_branch
-from bloom.git import get_last_tag_by_date
+from bloom.git import get_last_tag_by_version
 from bloom.git import has_changes
 from bloom.git import inbranch
 from bloom.git import show
+from bloom.git import tag_exists
 from bloom.git import track_branches
 
 from bloom.logging import ansi
@@ -306,6 +307,28 @@ def import_orig(tarball_path, target_branch, upstream_url, version):
         # Extract the tarball into the clean branch
         targz.extractall(os.getcwd(), members)
 
+        # Check for folder nesting (mostly hg)
+        items = []
+        for item in os.listdir(os.getcwd()):
+            if not item.startswith('.'):
+                items.append(item)
+        tarball_prefix = os.path.basename(tarball_path)[:-len('.tag.gz')]
+        if tarball_prefix in items:
+            debug('Removing nested tarball folder: ' + str(tarball_prefix))
+            tarball_prefix_path = os.path.join(os.getcwd(), tarball_prefix)
+            for item in os.listdir(tarball_prefix_path):
+                if item in ['.', '..']:
+                    continue
+                item_path = os.path.join(os.getcwd(), tarball_prefix, item)
+                debug(
+                    'moving ' + str(item_path) + ' to ' +
+                    str(os.path.join(os.getcwd(), item))
+                )
+                shutil.move(item_path, os.path.join(os.getcwd(), item))
+            shutil.rmtree(tarball_prefix_path)
+        else:
+            debug('No nested tarball folder found.')
+
         # Commit changes to the repository
         items = []
         for item in os.listdir(os.getcwd()):
@@ -393,13 +416,19 @@ def import_upstream(cwd, tmp_dir, args):
         # We have to search for the upstream tag
         else:
             if args.upstream_devel is not None:
-                warning("Overriding the bloom.conf upstream branch with " + \
+                warning("Overriding the bloom.conf upstream branch with " +
                         args.upstream_devel)
                 devel_branch = args.upstream_devel
             else:
                 devel_branch = upstream_branch
-            meta = auto_upstream_checkout(upstream_repo,
-                                             upstream_url, devel_branch)
+            if args.upstream_version is not None:
+                meta = auto_upstream_checkout(
+                    upstream_repo, upstream_url, devel_branch
+                )
+            else:
+                meta = {
+                    'version': args.upstream_version
+                }
             if type(meta) not in [dict] and meta != 0:
                 return meta
 
@@ -420,7 +449,7 @@ def import_upstream(cwd, tmp_dir, args):
             upstream_repo.export_repository(version, tarball_path)
 
     # Get the gbp version elements from either the last tag or the default
-    last_tag = get_last_tag_by_date()
+    last_tag = get_last_tag_by_version()
     if last_tag == '':
         gbp_major, gbp_minor, gbp_patch = segment_version(version)
     else:
@@ -445,15 +474,17 @@ import version.
     Removing conflicting tag before continuing \
 because the '--replace' options was specified.\
 """.format(version))
-                execute_command('git tag -d {0}'.format('upstream/' + version))
-                execute_command('git push origin :refs/tags/'
-                                '{0}'.format('upstream/' + version))
             else:
                 warning("""\
 The upstream version, {0}, is equal to a previous import version. \
 git-buildpackage will fail, if you want to replace the existing \
 upstream import use the '--replace' option.\
 """.format(version))
+    if args.replace:
+        if tag_exists('upstream/' + version):
+            execute_command('git tag -d {0}'.format('upstream/' + version))
+            execute_command('git push origin :refs/tags/'
+                            '{0}'.format('upstream/' + version))
 
     # Look for upstream branch
     if not branch_exists('upstream', local_only=True):
